==> tdiary-devel-2.1.2.tbz: share/examples/tdiary-devel/misc/plugin/ja/amazon.rb <==
#
# English resource of amazon plugin $Revision: 1.4 $
#

#
# isbn_image_left: ꤷISBNνƤclass="left"ɽ
#   ѥ᥿:
#     asin:    ASINޤISBN(ɬ)
#     comment: (ά)
#
# isbn_image_right: ꤷISBNνƤclass="right"ɽ
#   ѥ᥿:
#     asin:    ASINޤISBN(ɬ)
#     comment: (ά)
#
# isbn_image: ꤷISBNνƤclass="amazon"ɽ
#     asin:    ASINޤISBN(ɬ)
#     comment: (ά)
#
# isbn: amazon˥ʤʰץС
#     asin:    ASINޤISBN(ɬ)
#     comment: (ɬ)
#
#   ASINȤϥޥȼξʴIDǤ
#   ҤISBNASINϤȽҤɽޤ
#
#   줾쾦ʲĤʤä
#       <a href="amazonΥڡ">̾</a>
#   Τ褦˾̾ɽޤ
#   ȤҤƤϾ̾ȤƤѤޤ
#
# tdiary.confˤ:
#   @options['amazon.aid']:      IDꤹ뤳ȤǡʬΥ
#                                ȥץѤǤޤ
#                                Υץ̤ѹǽǤ
#   @options['amazon.hideconf']: ̾ǥIDԲǽ
#                                ˤ硢trueꤷޤ
#   @options['amazon.proxy']:    host:post׷HTTP proxyꤹ
#                                ProxyͳAmazonξޤ
#   @options['amazon.imgsize']:  ɽ륤᡼Υꤷޤ
#                                (0:  1:  2:)
#   @options['amazon.hidename']: class="amazon"ΤȤ˾̾ɽ
#                                ʤ硢trueꤷޤ
#   @options['amazon.nodefault']: ǥեȤΥ᡼ɽʤ
#                                 trueꤷޤ
#
#
# աϢ١www.amazon.co.jpΥȥץ
# ǧξѤƲ
#

@amazon_url = 'http://www.amazon.co.jp/exec/obidos/ASIN'
@amazon_item_name = /^Amazon.co.jp (.*)<.*$/
@amazon_item_image = %r|(<img src="(http://images-jp\.amazon\.com/images/P/(.*MZZZZZZZ_?.jpg))".*?>)|i
@amazon_label_conf ='Amazonץ饰'
@amazon_label_aid = 'AmazonIDλ'
@amazon_label_imgsize = 'ɽ륤᡼Υ'
@amazon_label_large = '礭'
@amazon_label_regular = ''
@amazon_label_small = ''
@amazon_label_title = 'isbn_imageץ饰Ǿ̾'
@amazon_label_hide = 'ɽʤ'
@amazon_label_show = 'ɽ'
@amazon_label_notfound = '᡼ĤʤȤ'
@amazon_label_usetitle = '̾ɽ'
@amazon_label_usedefault = 'ǥեȤΥ᡼Ȥ'
@amazon_label_clearcache = 'åκ'
@amazon_label_clearcache_desc = '᡼ϢΥå(Amazonɽ̷⤬˻Ʋ)'
@amazon_label_over18 = 'Ⱦʤν'
@amazon_label_over18_desc = 'ȾʤνƤ롣Ǥ˼ѤߤνƤ̵櫓ǤϤʤΤǡɬפ˱ƥåƲ'

==> tdiary-devel-2.1.3.tbz: share/examples/tdiary-devel/misc/plugin/ja/amazon.rb <==
#
# English resource of amazon plugin $Revision: 1.9 $
#
# Copyright (C) 2002 HAL99 <hal99@mtj.biglobe.ne.jp>
# You can redistribute it and/or modify it under GPL2.
#

#
# isbn_image_left: ꤷISBNνƤclass="left"ɽ
#   ѥ᥿:
#     asin:    ASINޤISBN(ɬ)
#     comment: (ά)
#
# isbn_image_right: ꤷISBNνƤclass="right"ɽ
#   ѥ᥿:
#     asin:    ASINޤISBN(ɬ)
#     comment: (ά)
#
# isbn_image: ꤷISBNνƤclass="amazon"ɽ
#     asin:    ASINޤISBN(ɬ)
#     comment: (ά)
#
# isbn: amazon˥ʤʰץС
#     asin:    ASINޤISBN(ɬ)
#     comment: (ɬ)
#
#   ASINȤϥޥȼξʴIDǤ
#   ҤISBNASINϤȽҤɽޤ
#
#   줾쾦ʲĤʤä
#       <a href="amazonΥڡ">̾</a>
#   Τ褦˾̾ɽޤ
#   ȤҤƤϾ̾ȤƤѤޤ
#
# tdiary.confˤ:
#   @options['amazon.aid']:      IDꤹ뤳ȤǡʬΥ
#                                ȥץѤǤޤ
#                                Υץ̤ѹǽǤ
#   @options['amazon.hideconf']: ̾ǥIDԲǽ
#                                ˤ硢trueꤷޤ
#   @options['amazon.proxy']:    host:post׷HTTP proxyꤹ
#                                ProxyͳAmazonξޤ
#   @options['amazon.imgsize']:  ɽ륤᡼Υꤷޤ
#                                (0:  1:  2:)
#   @options['amazon.hidename']: class="amazon"ΤȤ˾̾ɽ
#                                ʤ硢trueꤷޤ
#   @options['amazon.default_image_base']: ǥեȤΥ᡼Ǽ
#                                 URLꤷޤ̵ˤtDiary.org
#                                 ˤΤȤޤˤ
#                                 ץ饰amazonǥ쥯ȥˤPNG
#                                 ե򻲹ͤˤƲ
#   @options['amazon.nodefault']: ǥեȤΥ᡼ɽʤ
#                                 trueꤷޤ
#
#
# աϢ١www.amazon.co.jpΥȥץ
# ǧξѤƲ
#

@amazon_url = 'http://www.amazon.co.jp/exec/obidos/ASIN'
@amazon_ecs_url = 'http://webservices.amazon.co.jp/onca/xml'
@amazon_item_name = /^Amazon.co.jp (.*)<.*$/
@amazon_item_image = %r|(<img src="(http://images-jp\.amazon\.com/images/P/(.*MZZZZZZZ_?.jpg))".*?>)|i
@amazon_label_conf ='Amazon'
@amazon_label_aid = 'AmazonIDλ'
@amazon_label_imgsize = 'ɽ륤᡼Υ'
@amazon_label_large = '礭'
@amazon_label_regular = ''
@amazon_label_small = ''
@amazon_label_title = 'isbn_imageץ饰Ǿ̾'
@amazon_label_hide = 'ɽʤ'
@amazon_label_show = 'ɽ'
@amazon_label_notfound = '᡼ĤʤȤ'
@amazon_label_usetitle = '̾ɽ'
@amazon_label_usedefault = 'ǥեȤΥ᡼Ȥ'
@amazon_label_clearcache = 'åκ'
@amazon_label_clearcache_desc = '᡼ϢΥå(Amazonɽ̷⤬˻Ʋ)'
